==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=cpf
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Lakey lo sit', # MODIF
	'articles' => 'Bann zartik',
	'articles_auteur' => 'Bann zartik lotèr-la',
	'articles_populaires' => 'Bann zartik sak lé pli popilèr',
	'articles_rubrique' => 'Bann zartik andann ribrik-la',
	'aucun_article' => 'Néna pa okinn lartik si ladrès-la',
	'aucun_auteur' => 'Néna pa okinn lotèr si ladrès-la',
	'aucun_site' => 'Néna pa okin sitwèb si ladrès-la',
	'aucune_breve' => 'Néna pa okin titnouvèl si ladrès-la',
	'aucune_rubrique' => 'Néna pa okinn ribrik si ladrès-la',
	'autres_breves' => 'Bann zot tite-nouvèl',
	'autres_groupes_mots_clefs' => 'Bann zot bann molaklé',
	'autres_sites' => 'Bann zot sitwèb',

	// B
	'bonjour' => 'Oté',

	// C
	'commenter_site' => 'Donn out lavi si lo sit-la',

	// D
	'date' => 'Ladat',
	'dernier_ajout' => 'Dernyé piblikasyon',
	'dernieres_breves' => 'Bann derniyèr tit-nouvèl',
	'derniers_articles' => 'Bann dèrnyé zartik',
	'derniers_commentaires' => 'Bann dèrnyé lavi',
	'derniers_messages_forum' => 'Bann dèrnyé modékri andann bann forom',

	// E
	'edition_mode_texte' => 'Po édité andann mod tèks',
	'en_reponse' => 'Po réponn a :',
	'en_resume' => 'Po rézimé',
	'envoyer_message' => 'Po anvwayé inn modékri',
	'espace_prive' => 'Léspas privé',

	// H
	'hierarchie_site' => 'Bardrin lo sitwèb',

	// J
	'jours' => 'bann zour',

	// M
	'meme_auteur' => 'Pa lotèr minm sa-minm',
	'meme_rubrique' => 'Andan minm ribrik-la',
	'memes_auteurs' => 'Po bann zotèr minm',
	'message' => 'Modékri',
	'messages_forum' => 'Bann modékri andann forom', # MODIF
	'messages_recents' => 'Bann modékri la finn mèt an dernyé andan forom',
	'mots_clefs' => 'Bann molaklé',
	'mots_clefs_meme_groupe' => 'Bann molaklé andann lo minm bann sa-minm',

	// N
	'navigation' => 'Bat-karé si lo sit',
	'nom' => 'Non',
	'nouveautes' => 'Bann nouvèlté',
	'nouveautes_web' => 'Bann nouvèlté si lo sitwèb',
	'nouveaux_articles' => 'Bann nouvo lartik',
	'nouvelles_breves' => 'Bann nouvèl tite-nouvèl',

	// P
	'page_precedente' => 'lapaz dovan',
	'page_suivante' => 'Lapaz déyèr',
	'par_auteur' => 'sanm',
	'participer_site' => 'Ou pé mèt ansanm bann zot dalon po la vi lo sit-la, è propozé out prop bann zartik, si ou lé inskri anba-la. Inskri aou : ou sar gayn inn limèl i don aou out bann kodlaksé po léspas privé lo sit. ',
	'plan_site' => 'Lakart lo sit',
	'popularite' => 'Koman lé popilèr',
	'poster_message' => 'Anvwa in modékri',
	'proposer_site' => 'Ou pé propoz azout inn sit dann ribrik-la :',

	// R
	'repondre_article' => 'Po réponn si lartik-la',
	'repondre_breve' => 'Po réponn la tite-nouvèl-la',
	'resultats_recherche' => 'Kosa lo rodèr la finn trouvé',
	'retour_debut_forums' => 'Artourn bann débi bann forom',
	'rubrique' => 'Ribrik',
	'rubriques' => 'Bann ribrik',

	// S
	'signatures_petition' => 'Bann sinyatir',
	'site_realise_avec_spip' => 'Sit-la ni la fé èk SPIP',
	'sites_web' => 'Bann sitwèb',
	'sous_rubriques' => 'Bann souribrik',
	'suite' => 'laswit',
	'sur_web' => 'Si lo wèb',
	'syndiquer_rubrique' => 'Po sindiké ribrik-la',
	'syndiquer_site' => 'Po sindiké si lo sit',

	// T
	'texte_lettre_information' => 'Ala lalèt zinformasyon lo sit',
	'texte_lettre_information_2' => 'Lèt-la i ramas tout bann zartik èk bann tite-nouvèl dopwi', # MODIF

	// V
	'ver_imprimer' => 'Vèrsyon pou inprimé',
	'voir_en_ligne' => 'Anon vwar an liyn',
	'voir_squelette' => 'Apiy po télésarz léskélet lapaz-la'
);

==> spip_4.4.7+dfsg.orig.tar.xz: ecrire/lang/public_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=cpf
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Lakey lo sit', # MODIF
	'articles' => 'Bann zartik',
	'articles_auteur' => 'Bann zartik lotèr-la',
	'articles_populaires' => 'Bann zartik sak lé pli popilèr',
	'articles_rubrique' => 'Bann zartik andann ribrik-la',
	'aucun_article' => 'Néna pa okinn lartik si ladrès-la',
	'aucun_auteur' => 'Néna pa okinn lotèr si ladrès-la',
	'aucun_site' => 'Néna pa okin sitwèb si ladrès-la',
	'aucune_breve' => 'Néna pa okin titnouvèl si ladrès-la',
	'aucune_rubrique' => 'Néna pa okinn ribrik si ladrès-la',
	'autres_breves' => 'Bann zot tite-nouvèl',
	'autres_groupes_mots_clefs' => 'Bann zot bann molaklé',
	'autres_sites' => 'Bann zot sitwèb',

	// B
	'bonjour' => 'Oté',

	// C
	'commenter_site' => 'Donn out lavi si lo sit-la',

	// D
	'date' => 'Ladat',
	'dernier_ajout' => 'Dernyé piblikasyon',
	'dernieres_breves' => 'Bann derniyèr tit-nouvèl',
	'derniers_articles' => 'Bann dèrnyé zartik',
	'derniers_commentaires' => 'Bann dèrnyé lavi',
	'derniers_messages_forum' => 'Bann dèrnyé modékri andann bann forom',

	// E
	'edition_mode_texte' => 'Po édité andann mod tèks',
	'en_reponse' => 'Po réponn a :',
	'en_resume' => 'Po rézimé',
	'envoyer_message' => 'Po anvwayé inn modékri',
	'espace_prive' => 'Léspas privé',

	// H
	'hierarchie_site' => 'Bardrin lo sitwèb',

	// J
	'jours' => 'bann zour',

	// M
	'meme_auteur' => 'Pa lotèr minm sa-minm',
	'meme_rubrique' => 'Andan minm ribrik-la',
	'memes_auteurs' => 'Po bann zotèr minm',
	'message' => 'Modékri',
	'messages_forum' => 'Bann modékri andann forom', # MODIF
	'messages_recents' => 'Bann modékri la finn mèt an dernyé andan forom',
	'mots_clefs' => 'Bann molaklé',
	'mots_clefs_meme_groupe' => 'Bann molaklé andann lo minm bann sa-minm',

	// N
	'navigation' => 'Bat-karé si lo sit',
	'nom' => 'Non',
	'nouveautes' => 'Bann nouvèlté',
	'nouveautes_web' => 'Bann nouvèlté si lo sitwèb',
	'nouveaux_articles' => 'Bann nouvo lartik',
	'nouvelles_breves' => 'Bann nouvèl tite-nouvèl',

	// P
	'page_precedente' => 'lapaz dovan',
	'page_suivante' => 'Lapaz déyèr',
	'par_auteur' => 'sanm',
	'participer_site' => 'Ou pé mèt ansanm bann zot dalon po la vi lo sit-la, è propozé out prop bann zartik, si ou lé inskri anba-la. Inskri aou : ou sar gayn inn limèl i don aou out bann kodlaksé po léspas privé lo sit. ',
	'plan_site' => 'Lakart lo sit',
	'popularite' => 'Koman lé popilèr',
	'poster_message' => 'Anvwa in modékri',
	'proposer_site' => 'Ou pé propoz azout inn sit dann ribrik-la :',

	// R
	'repondre_article' => 'Po réponn si lartik-la',
	'repondre_breve' => 'Po réponn la tite-nouvèl-la',
	'resultats_recherche' => 'Kosa lo rodèr la finn trouvé',
	'retour_debut_forums' => 'Artourn bann débi bann forom',
	'rubrique' => 'Ribrik',
	'rubriques' => 'Bann ribrik',

	// S
	'signatures_petition' => 'Bann sinyatir',
	'site_realise_avec_spip' => 'Sit-la ni la fé èk SPIP',
	'sites_web' => 'Bann sitwèb',
	'sous_rubriques' => 'Bann souribrik',
	'suite' => 'laswit',
	'sur_web' => 'Si lo wèb',
	'syndiquer_rubrique' => 'Po sindiké ribrik-la',
	'syndiquer_site' => 'Po sindiké si lo sit',

	// T
	'texte_lettre_information' => 'Ala lalèt zinformasyon lo sit',
	'texte_lettre_information_2' => 'Lèt-la i ramas tout bann zartik èk bann tite-nouvèl dopwi', # MODIF

	// V
	'ver_imprimer' => 'Vèrsyon pou inprimé',
	'voir_en_ligne' => 'Anon vwar an liyn',
	'voir_squelette' => 'Apiy po télésarz léskélet lapaz-la',
];
